# # Module file: hmrc_rate.py
# enviroment
import pandas as pd
import numpy as np
import requests
from bs4 import BeautifulSoup

# http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-0222.XML

def hmrc_to_dataframe(month, year):
    url = f"http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-{month}{year[2:]}.XML"
    document = requests.get(url)
    soup = BeautifulSoup(document.content, "xml")
    countryName = soup.find_all('countryName')
    countryCode = soup.find_all('countryCode')
    currencyName = soup.find_all('currencyName')
    currencyCode = soup.find_all('currencyCode')
    rateNew = soup.find_all('rateNew')

    currency_data = []
    for i in range(0, len(countryName)):
        rows = [countryName[i].get_text(),
                countryCode[i].get_text(),
                currencyName[i].get_text(),
                currencyCode[i].get_text(),
                rateNew[i].get_text()]
        currency_data.append(rows)

    exchange_rate_df = pd.DataFrame(currency_data, columns=[
                                    'countryName', 'countryCode', 'currencyName', 'currencyCode', 'rateNew'])
    exchange_rate_df['reported_month_year'] = url[-8:-4]
    exchange_rate_df['exchageRate_starDate'] = pd.to_datetime(
        exchange_rate_df['reported_month_year'], format="%m%y")
    return exchange_rate_df


import setuptools
# lo
with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="hmrcCurrencyRate",  
    version="0.0.9",
    author="James Huang",
    author_email="yichan.huang93@gmail.com",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/YChanHuang/hmrcCurrencyRate",
    packages=setuptools.find_packages(),
    # packages = ['hmrc_currency_rate'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)